==> thousandeyes_sdk_instant_tests-1.3.0.tar.gz: thousandeyes_sdk_instant_tests-1.3.0/docs/SipServerInstantTestResponse.md <==
# SipServerInstantTestResponse


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_by** | **str** | User that created the test. | [optional] [readonly] 
**created_date** | **datetime** | UTC created date (ISO date-time format). | [optional] [readonly] 
**description** | **str** | A description of the test. | [optional] 
**live_share** | **bool** | Indicates if the test is shared with the account group. | [optional] [readonly] 
**modified_by** | **str** | User that modified the test. | [optional] [readonly] 
**modified_date** | **datetime** | UTC last modification date (ISO date-time format). | [optional] [readonly] 
**saved_event** | **bool** | Indicates if the test is a saved event. | [optional] [readonly] 
**test_id** | **str** | Each test is assigned an unique ID; this is used to access test information and results from other endpoints. | [optional] [readonly] 
**test_name** | **str** | The name of the test. Test name must be unique. | [optional] 
**type** | **str** |  | [optional] [readonly] 
**links** | [**TestLinks**](TestLinks.md) |  | [optional] 
**labels** | [**List[TestLabel]**](TestLabel.md) |  | [optional] [readonly] 
**shared_with_accounts** | [**List[SharedWithAccount]**](SharedWithAccount.md) |  | [optional] [readonly] 
**mtu_measurements** | **bool** | Set &#x60;true&#x60; to measure MTU sizes on network from agents to the target. | [optional] 
**network_measurements** | **bool** | Enable or disable network measurements. Set to true to enable or false to disable network measurements. | [optional] [default to True]
**num_path_traces** | **int** | Number of path traces executed by the agent. | [optional] [default to 3]
**options_regex** | **str** | Options regex, this field does not require escaping. | [optional] 
**path_trace_mode** | [**TestPathTraceMode**](TestPathTraceMode.md) |  | [optional] 
**probe_mode** | [**TestProbeMode**](TestProbeMode.md) |  | [optional] 
**register_enabled** | **bool** | Set to true to perform SIP registration on the test target with the SIP REGISTER command. | [optional] [default to False]
**sip_target_time** | **int** | Target time for test completion in milliseconds. | [optional] 
**sip_time_limit** | **int** | Time limit in milliseconds. | [optional] [default to 5]
**fixed_packet_rate** | **int** | Sets packets rate sent to measure the network in packets per second. | [optional] 
**ipv6_policy** | [**TestIpv6Policy**](TestIpv6Policy.md) |  | [optional] 
**agents** | [**List[Agent]**](Agent.md) | Contains list of agents. | [optional] [readonly] 
**auth_user** | **str** | Username for authentication with SIP server. | [optional] 
**password** | **str** | Password for Basic/NTLM authentication. | [optional] 
**port** | **int** | Target port. | [default to 49153]
**protocol** | [**SipTestProtocol**](SipTestProtocol.md) |  | [optional] 
**sip_registrar** | **str** | SIP server to be tested, specified by domain name or IP address. | [optional] 
**user** | **str** | Username for SIP registration, should be unique within a ThousandEyes account group. | [optional] 

## Example

```python
from thousandeyes_sdk.instant_tests.models.sip_server_instant_test_response import SipServerInstantTestResponse

# TODO update the JSON string below
json = "{}"
# create an instance of SipServerInstantTestResponse from a JSON string
sip_server_instant_test_response_instance = SipServerInstantTestResponse.from_json(json)
# print the JSON string representation of the object
print(SipServerInstantTestResponse.to_json())

# convert the object into a dict
sip_server_instant_test_response_dict = sip_server_instant_test_response_instance.to_dict()
# create an instance of SipServerInstantTestResponse from a dict
sip_server_instant_test_response_from_dict = SipServerInstantTestResponse.from_dict(sip_server_instant_test_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> thousandeyes_sdk_instant_tests-2.0.0.tar.gz: thousandeyes_sdk_instant_tests-2.0.0/docs/SipServerInstantTestResponse.md <==
# SipServerInstantTestResponse


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_by** | **str** | User that created the test. | [optional] [readonly] 
**created_date** | **datetime** | UTC created date (ISO date-time format). | [optional] [readonly] 
**description** | **str** | A description of the test. | [optional] 
**live_share** | **bool** | Indicates if the test is shared with the account group. | [optional] [readonly] 
**modified_by** | **str** | User that modified the test. | [optional] [readonly] 
**modified_date** | **datetime** | UTC last modification date (ISO date-time format). | [optional] [readonly] 
**saved_event** | **bool** | Indicates if the test is a saved event. | [optional] [readonly] 
**test_id** | **str** | Each test is assigned an unique ID; this is used to access test information and results from other endpoints. | [optional] [readonly] 
**test_name** | **str** | The name of the test. Test name must be unique. | [optional] 
**type** | **str** |  | [optional] [readonly] 
**links** | [**TestLinks**](TestLinks.md) |  | [optional] 
**labels** | [**List[TestLabel]**](TestLabel.md) |  | [optional] [readonly] 
**shared_with_accounts** | [**List[SharedWithAccount]**](SharedWithAccount.md) |  | [optional] [readonly] 
**mtu_measurements** | **bool** | Set &#x60;true&#x60; to measure MTU sizes on network from agents to the target. | [optional] 
**network_measurements** | **bool** | Enable or disable network measurements. Set to true to enable or false to disable network measurements. | [optional] [default to True]
**num_path_traces** | **int** | Number of path traces executed by the agent. | [optional] [default to 3]
**options_regex** | **str** | Options regex, this field does not require escaping. | [optional] 
**path_trace_mode** | [**TestPathTraceMode**](TestPathTraceMode.md) |  | [optional] 
**probe_mode** | [**TestProbeMode**](TestProbeMode.md) |  | [optional] 
**register_enabled** | **bool** | Set to true to perform SIP registration on the test target with the SIP REGISTER command. | [optional] [default to False]
**sip_target_time** | **int** | Target time for test completion in milliseconds. | [optional] 
**sip_time_limit** | **int** | Time limit in milliseconds. | [optional] [default to 5]
**fixed_packet_rate** | **int** | Sets packets rate sent to measure the network in packets per second. | [optional] 
**ipv6_policy** | [**TestIpv6Policy**](TestIpv6Policy.md) |  | [optional] 
**auth_user** | **str** | Username for authentication with SIP server. | [optional] 
**password** | **str** | Password for Basic/NTLM authentication. | [optional] 
**port** | **int** | Target port. | [default to 49153]
**protocol** | [**SipTestProtocol**](SipTestProtocol.md) |  | [optional] 
**sip_registrar** | **str** | SIP server to be tested, specified by domain name or IP address. | [optional] 
**user** | **str** | Username for SIP registration, should be unique within a ThousandEyes account group. | [optional] 
**agents** | [**List[AgentResponse]**](AgentResponse.md) | Contains list of agents. | [optional] 

## Example

```python
from thousandeyes_sdk.instant_tests.models.sip_server_instant_test_response import SipServerInstantTestResponse

# TODO update the JSON string below
json = "{}"
# create an instance of SipServerInstantTestResponse from a JSON string
sip_server_instant_test_response_instance = SipServerInstantTestResponse.from_json(json)
# print the JSON string representation of the object
print(SipServerInstantTestResponse.to_json())

# convert the object into a dict
sip_server_instant_test_response_dict = sip_server_instant_test_response_instance.to_dict()
# create an instance of SipServerInstantTestResponse from a dict
sip_server_instant_test_response_from_dict = SipServerInstantTestResponse.from_dict(sip_server_instant_test_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
